var currentChatUser;

/**
* Creates a new chat tab and chat item.
* @param {string} username - user ID
* @param {string} fullName - user's name
*/
function newChatTab(userName, fullName) {

    if ($("#tabItem_" + userName).length != 0)
        return;

    // insert new tab item for the user
    $("#lastTab").before('' +
        '<div class="tabItem" id="tabItem_' + userName + '">' +
            '<a href="javascript:openChat(\'' + userName + '\')">' + fullName + '</a><a class="closeChat" title="Close" href="javascript:closeChat(\'' + userName + '\')">[X]</a>' +
        '</div>');

    // insert tab content holder
    $("#tabContents").append('<div id="tabContent_' + userName + '" class="tabContent hidden"></div>');

    // show the currently opened chat window
    showChatTab(userName);
}

/**
* Opens a chat with the user.
* @param {string} username - user ID
*/
function showChatTab(username) {

    // show the proper tab content
    $(".tabContent").hide();
    $("#tabContent_" + username).show();
    $("#tabItem_" + username).show();

    // set current tab style to passive
    setTabClass(currentChatUser, "passiveTab");

    // set current tab style to active
    setTabClass(username, "activeTab");

    currentChatUser = username;
}


/**
* Closes the chat with the user.
* @param {string} username - user ID
*/
function closeChat(userName) {
    $("#tabContent_" + userName).remove();
    $("#tabItem_" + userName).remove();
}


/**
* Updates the class of the given tab item.
* @param {string} tabItem - The ID of the tab item.
* @param {string} className - The name of the css class.
*/
function setTabClass(tabItem, className) {
    $("#tabItem_" + tabItem).removeClass();
    $("#tabItem_" + tabItem).addClass("tabItem");
    $("#tabItem_" + tabItem).addClass(className);
}

/**
* Inserts a chat entry.
* @param {string} username - The username of the sender.
* @param {string} content - chat message.
* @param {string} date - current timestamp.
* @param {boolean} self - true if the sender was the current user.
* @param {string} sender - who sent the last message.
*/
function appendMessage(username, content, date, self, sender) {

    // do not post empty message
    if (jQuery.isEmptyObject(content))
        return;

    // insert the message to the proper chat window
    var style = (self) ? "ownMessage" : "otherMessage";

    $("#tabContent_" + username).append('' +
        '<div class="chatEntry ' + style + '">' +
            '<div class="chatEntrySender">' + sender + ':  </div>' +
            '<div class="chatEntryContent">' + content + '</div>' +
            '<div class="chatDate">' + date + '</div>' +
            '<div class="clear"></div>' +
        '</div>');

    // clear the input box
    $("#chatInput").val("");
}